@@ -122,11 +122,13 @@ class Equation(object):
         # Rewrite the equation into canonical form
         equation = _rewrite(variables, parameters, self.equation)
 
-        sides = equation.split('=')
+        # Find the location of the equal sign, also need to ignore
+        # things like <=, >=, ==, !=, etc...
+        sides = re.split(r"(?<![<>=!])=(?!=)", equation)
         if len(sides) != 2:
             raise EquationError('equals-sign',
                                 self.equation,
-                                'there must be one and only one "=" sign')
+                                "Equation must be of the form f(...) = g(...)")
 
         transforms = (factorial_notation, auto_number)
 
